@@ -16,6 +16,8 @@ DEFAULT_DS_PATHS: Mapping[str, str] = {
     "doublebind-negative": f"{MODULE_PATH}/data/datasets/doublebind-negative.jsonl",
     "doublebind-positive-1token": f"{MODULE_PATH}/data/datasets/doublebind-positive-1token.jsonl",
     "doublebind-positive": f"{MODULE_PATH}/data/datasets/doublebind-positive.jsonl",
+    "doublebind-likable": f"{MODULE_PATH}/data/datasets/doublebind-likable.jsonl",
+    "doublebind-unlikable": f"{MODULE_PATH}/data/datasets/doublebind-unlikable.jsonl",
     "male-stereotypes": f"{MODULE_PATH}/data/datasets/male-stereotypes.jsonl",
     "female-stereotypes": f"{MODULE_PATH}/data/datasets/female-stereotypes.jsonl",
     "tiny-test": f"{MODULE_PATH}/data/datasets/tiny-test.jsonl",
@@ -26,9 +28,15 @@ DEFAULT_DS_PATHS: Mapping[str, str] = {
 DEFAULT_AUGMENTED_DS_PATHS: Mapping[str, str] = {
     "doublebind-positive-paraphrased": f"{MODULE_PATH}/data/augdatasets/doublebind-positive-paraphrased.jsonl",
     "doublebind-negative-paraphrased": f"{MODULE_PATH}/data/augdatasets/doublebind-negative-paraphrased.jsonl",
+    "doublebind-likable-paraphrased": f"{MODULE_PATH}/data/augdatasets/doublebind-likable-paraphrased.jsonl",
+    "doublebind-unlikable-paraphrased": f"{MODULE_PATH}/data/augdatasets/doublebind-unlikable-paraphrased.jsonl",
+    "male-stereotypes": f"{MODULE_PATH}/data/augdatasets/male-stereotypes.jsonl",
+    "female-stereotypes": f"{MODULE_PATH}/data/augdatasets/female-stereotypes.jsonl",
     "tiny-test-aug-gender": f"{MODULE_PATH}/data/augdatasets/tiny-test.jsonl",
     "twitter-sentiment-aug-gender": f"{MODULE_PATH}/data/augdatasets/twitter-sentiment.jsonl",
     "hate-aug-muslim": f"{MODULE_PATH}/data/augdatasets/hate-test-muslims.jsonl",
+    "bias-from-probs": f"{MODULE_PATH}/data/augdatasets/bias-from-probs.jsonl",
+    "simple-gender": f"{MODULE_PATH}/data/augdatasets/simple-gender.jsonl",
 }
 
 
@@ -77,6 +85,7 @@ class Dataset:
         return Dataset(samples)
 
     def augment(self, converters: Iterable[Augmenter]) -> "AugmentedDataset":
+        """Use the augmenters to generate variations of this dataset."""
         return generate_all_variations(converters, self)
 
 
@@ -108,6 +117,16 @@ class AugmentedDataset:
                 json.dump(sample.to_json_dict(), f)
                 f.write("\n")
 
+    def to_unbiased_dataset(self) -> Dataset:
+        """Make each variation a new input."""
+        new_samples: List[Sample] = []
+
+        for aug_sample in self.samples:
+            for variation in aug_sample.get_variations():
+                new_samples.append(Sample(input=variation.text, outputs=aug_sample.outputs))
+
+        return Dataset(new_samples)
+
 
 def generate_variations(variation: Variation, augmenter: Augmenter) -> List[Variation]:
     if isinstance(augmenter, Paraphraser):
